Changelog — django-guardian v1.0.0.beta1 documentation

### Navigation

- index
- modules |
- previous |
- django-guardian v1.0.0.beta1 documentation »
- Development »

# Changelog

## Release 1.0.0.alpha2 (Dec 2, 2010)

- Added possibility to operate with global permissions for assign and remove_perm shortcut functions
- Added possibility to generate PDF documentation
- Fixed some tests

## Release 1.0.0.alpha1 (Nov 23, 2010)

- Fixed admin templates not included in MANIFEST.in
- Fixed admin integration codes

## Release 1.0.0.pre (Nov 23, 2010)

- Added admin integration
- Added reusable forms for object permissions management

## Release 0.2.3 (Nov 17, 2010)

- Added `guardian.shortcuts.get_users_with_perms` function
- Added AUTHORS file

## Release 0.2.2 (Oct 19, 2010)

- Fixed migrations order (thanks to Daniel Rech)

## Release 0.2.1 (Oct 3, 2010)

- Fixed migration (it wasn’t actually updating object_pk field)

## Release 0.2.0 (Oct 3, 2010)

### Fixes

- #4: guardian now supports models with not-integer primary keys and they don’t need to be called “id”.

  Important

  For 0.1.X users: it is required to migrate guardian in your projects. Add `south` to `INSTALLED_APPS` and run:

      python manage.py syncdb
      python manage.py migrate guardian 0001 --fake
      python manage.py migrate guardian

### Improvements

- Added South migrations support

## Release 0.1.1 (Sep 27, 2010)

### Improvements

- Added view decorators: `permission_required` and `permission_required_403`

## Release 0.1.0 (Jun 6, 2010)

- Initial public release

### Navigation

- index
- modules |
- previous |
- django-guardian v1.0.0.beta1 documentation »
- Development »